/* xrdev/examples/battery_display.c
 *
 * simple display of current battery voltages
 *
 *                             ** COPYRIGHT NOTICE **
 *
 * Copyright (c) 1999, Nomadic Technologies, Inc.
 *
 * The contents of this file is copyrighted by Nomadic Technologies, Inc, and
 * is protected by United States copyright laws.  Unauthorized copying is
 * prohibited.  All rights reserved.
 *
 */

#include <stdio.h>
#include <stdlib.h>

#include "Nclient.h"

#include "robot_arg.h"



/* ------------------------------------------------------------------------
 * Function:     Usage
 * Purpose:      print the command line options and exit
 * Arguments:    *program_name : argv[0]
 * ------------------------------------------------------------------------ */
static void Usage(const char *program_name)
{
  fprintf(stderr, "Usage: %s [--host host[:port]] [--robot_id N]\n",
	  program_name);
  exit(-1);
}



int main(int argc, char *argv[])
{
  char *sched_host;
  const char *argv0;
  unsigned short sched_port;
  int i, error;
  long robot_id;
  struct N_RobotState *rs;

  argv0 = ARG_GetProgramName(argv[0]);
  
  /* get the robot ID and scheduler from the command line */
  sched_host = "localhost";
  sched_port = 7073;
  robot_id = 1;
  if (ARG_GetStandardArgs(&argc, &argv, &sched_host, &sched_port, &robot_id))
  {
    Usage(argv0);
  }

  /* initialize the client library and connect to our robot */
  if ((error = N_InitializeClient(sched_host, sched_port)) != N_NO_ERROR ||
      (error = N_ConnectRobot(robot_id)) != N_NO_ERROR)
  {
    fprintf(stderr, "%s: error connecting to %s:%d (%d).\n", argv0,
	    sched_host, sched_port, error);
    exit(-1);
  }

  /* get a pointer to the state structure */
  rs = N_GetRobotState(robot_id);

  /* fill in rs->BatterySet with the current values */
  if ((error = N_GetBattery(robot_id)) != N_NO_ERROR)
  {
    fprintf(stderr, "%s: error retrieving battery data (%d).\n", argv0, error);
    exit(-1);
  }

  for (i = 0; i < rs->BatterySet.BatteryCount; ++i)
  {
    printf("Battery %2d: %ld mV\n", i, rs->BatterySet.Battery[i].Voltage);
  }

  N_DisconnectRobot(robot_id);
  return 0;
}
