/* xrdev/examples/conf_display.c
 *
 * simple continuous display of current integrated configuration
 *
 *                             ** COPYRIGHT NOTICE **
 *
 * Copyright (c) 1999, Nomadic Technologies, Inc.
 *
 * The contents of this file is copyrighted by Nomadic Technologies, Inc, and
 * is protected by United States copyright laws.  Unauthorized copying is
 * prohibited.  All rights reserved.
 *
 */

#include <signal.h>
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>

#include "Nclient.h"

#include "robot_arg.h"


/* flag, set by the signal trapper to exit the main loop */
BOOL conf_done;



/* ------------------------------------------------------------------------
 * Function:     Usage
 * Purpose:      print the command line options and exit
 * Arguments:    *program_name : argv[0]
 * ------------------------------------------------------------------------ */
static void Usage(const char *program_name)
{
  fprintf(stderr, "Usage: %s [--host host[:port]] [--robot_id N]\n",
	  program_name);
  exit(-1);
}



/* ------------------------------------------------------------------------
 * Function:     SignalTrap
 * Purpose:      catch process interrupts, so that we can exit the main
 *                 loop and clean up after ourselves
 * ------------------------------------------------------------------------ */
static void SignalTrap(int signal_num)
{
  conf_done = TRUE;
  return;
}



int main(int argc, char *argv[])
{
  char *sched_host;
  const char *argv0;
  unsigned short sched_port;
  int error;
  long robot_id;
  struct N_RobotState *rs;

  argv0 = ARG_GetProgramName(argv[0]);

  /* get the robot ID and scheduler from the command line */
  sched_host = "localhost";
  sched_port = 7073;
  robot_id = 1;
  if (ARG_GetStandardArgs(&argc, &argv, &sched_host, &sched_port, &robot_id))
  {
    Usage(argv0);
  }

  /* initialize the client library and connect to our robot */
  if ((error = N_InitializeClient(sched_host, sched_port)) != N_NO_ERROR ||
      (error = N_ConnectRobot(robot_id)) != N_NO_ERROR)
  {
    fprintf(stderr, "%s: error connecting to %s:%d (%d).\n", argv0,
	    sched_host, sched_port, error);
    exit(-1);
  }

  rs = N_GetRobotState(robot_id);
  rs->Integrator.TimeStampActive = TRUE;

  /* loop until SIGINT */
  conf_done = FALSE;
  signal(SIGINT, SignalTrap);
  while (!conf_done)
  {
    if ((error = N_GetIntegratedConfiguration(robot_id)) != N_NO_ERROR)
    {
      printf("%s retrieval of integrated configuration failed (%d).\n",
	     argv0, error);
      exit(-1);
    }

    printf("-------X- -------Y- --Theta1- --Theta3- -Timestamp-\n"
	   "%9ld %9ld %9ld %9ld   %9lu\n\n",
	   rs->Integrator.x, rs->Integrator.y, rs->Integrator.Steering,
	   rs->Integrator.Rotation, rs->Integrator.TimeStamp);
    sleep(1);
  }

  N_DisconnectRobot(robot_id);
  return 0;
}
